@@ -39,8 +39,10 @@
     if (unlockEnvironment_(asNamespace("base"))) {
         env <- as.environment("package:base")
         do.call("unlockBinding", list(sym = "print.data.frame", env = env))
-        env$`print.data.frame` <- function (x, ..., digits = NULL, quote = FALSE,
-            right = TRUE, row.names = TRUE, max = NULL) {
+        env$`print.data.frame` <- function (
+            x, ..., digits = NULL, quote = FALSE,
+            right = TRUE, row.names = TRUE, max = NULL
+        ) {
             n <- length(row.names(x))
             if (length(x) == 0L) {
                 do.call("cat", list(
@@ -73,11 +75,18 @@
                         n0
                         else n)
                     else row.names
-                do.call("print", list(m, ..., quote = quote, right = right, max = max))
+                do.call(
+                    "print",
+                    list(m, ..., quote = quote, right = right, max = max)
+                )
                 if (omit)
-                    do.call("cat", list(
-                        " [ reached 'max' / getOption(\"max.print\") -- omitted",
-                        n - n0, "rows ]\n"
+                    do.call(
+                        "cat",
+                        list(
+                            " [ reached 'max' /",
+                            "getOption(\"max.print\") -- omitted",
+                            n - n0,
+                            "rows ]\n"
                         )
                     )
             }
@@ -101,7 +110,12 @@
             }
             lens <- vapply(rval, NROW, 1)
             if (any(lens != nr)) {
-                warning("corrupt data frame: columns will be truncated or padded with NAs")
+                warning(
+                    paste(
+                        "corrupt data frame: columns will be",
+                        "truncated or padded with NAs"
+                    )
+                )
                 for (i in seq_len(nc)) {
                     len <- NROW(rval[[i]])
                     if (len == nr)
@@ -122,8 +136,10 @@
                 if (is.character(rval[[i]]) && inherits(rval[[i]], "character"))
                     oldClass(rval[[i]]) <- "AsIs"
             }
-            y <- as.data.frame.list(rval, row.names = seq_len(nr), col.names = names(x),
-                optional = TRUE, fix.empty.names = FALSE, cut.names = TRUE)
+            y <- as.data.frame.list(
+                    rval, row.names = seq_len(nr), col.names = names(x),
+                    optional = TRUE, fix.empty.names = FALSE, cut.names = TRUE
+                )
             attr(y, "row.names") <- row.names(x)
             return(y)
         }
@@ -167,7 +183,7 @@
             if(make.row.names) {
                 rlabs <- rows
                 env <- new.env()
-                env$autoRnms <- TRUE 
+                env$autoRnms <- TRUE
                 Make.row.names <- function(nmi, ri, ni, nrow) {
                     if(nzchar(nmi)) {
                     if(env$autoRnms) env$autoRnms <- FALSE
@@ -175,12 +191,18 @@
                     else if(ni > 1L) paste(nmi, ri, sep = ".")
                     else nmi
                     }
-                    else if(env$autoRnms && nrow > 0L && identical(ri, seq_len(ni)))
+                    else if(
+                        env$autoRnms && nrow > 0L && identical(ri, seq_len(ni))
+                    )
                     as.integer(seq.int(from = nrow + 1L, length.out = ni))
                     else {
-                    if(env$autoRnms && (nrow > 0L || !identical(ri, seq_len(ni))))
-                        env$autoRnms <- FALSE
-                    ri
+                        if(
+                            env$autoRnms && (nrow > 0L ||
+                            !identical(ri, seq_len(ni)))
+                        ) {
+                            env$autoRnms <- FALSE
+                        }
+                        ri
                     }
                 }
             }
@@ -202,18 +224,22 @@
                     clabs <- names(xi)
                     else {
                             if(length(xi) != length(clabs))
-                                stop("numbers of columns of arguments do not match")
+                                stop(
+                                  "numbers of columns of arguments do not match"
+                                )
                         pi <- match.names(clabs, names(xi))
                         if( !is.null(pi) ) perm[[i]] <- pi
                     }
                     rows[[i]] <- seq.int(from = nrow + 1L, length.out = ni)
-                    if(make.row.names) rlabs[[i]] <- Make.row.names(nmi, ri, ni, nrow)
+                    if(make.row.names) rlabs[[i]] <- Make.row.names(
+                        nmi, ri, ni, nrow
+                    )
                     nrow <- nrow + ni
                     if(is.null(value)) { 
                         value <- unclass(xi)
                         nvar <- length(value)
                         lxi <- vector("list", nvar)
-                        xideclared <- sapply(xi, is.declared)
+                        xideclared <- vapply(xi, is.declared, TRUE)
                         names(lxi) <- names(xideclared)
                         lxi[xideclared] <- lapply(xi[xideclared], function(x) {
                             list(
@@ -287,17 +313,27 @@
                     ni <- range(lengths(xi))
                     if(ni[1L] == ni[2L])
                     ni <- ni[1L]
-                    else stop("invalid list argument: all variables should have the same length")
+                    else stop(
+                        paste(
+                            "invalid list argument: all variables",
+                            "should have the same length"
+                        )
+                    )
                         ri <- seq_len(ni)
                     rows[[i]] <- seq.int(from = nrow + 1L, length.out = ni)
-                    if(make.row.names) rlabs[[i]] <- Make.row.names(nmi, ri, ni, nrow)
+                    if(make.row.names) rlabs[[i]] <- Make.row.names(
+                        nmi, ri, ni, nrow
+                    )
                     nrow <- nrow + ni
                     if(length(nmi <- names(xi)) > 0L) {
                         if(is.null(clabs))
                             clabs <- nmi
                         else {
-                                    if(length(xi) != length(clabs))
-                                        stop("numbers of columns of arguments do not match")
+                            if (length(xi) != length(clabs)) {
+                                stop(
+                                  "numbers of columns of arguments do not match"
+                                )
+                            }
                             pi <- match.names(clabs, nmi)
                             if( !is.null(pi) ) perm[[i]] <- pi
                         }
@@ -333,7 +369,9 @@
                     ordered = ordCol[j])
             if(any(has.dim)) { 
                 jdim <- pseq[has.dim]
-                if(!all(df <- vapply(jdim, function(j) inherits(value[[j]],"data.frame"), NA))) {
+                if(!all(df <- vapply(
+                    jdim, function(j) inherits(value[[j]],"data.frame"), NA
+                ))) {
                     rmax <- max(unlist(rows))
                     for(j in jdim[!df]) {
                 dn <- dimnames(vj <- value[[j]])
@@ -350,9 +388,15 @@
             if(!is.list(xi))
                 if((ni <- length(xi)) != nvar) {
                 if(ni && nvar %% ni != 0)
-                    warning(gettextf(
-                "number of columns of result, %d, is not a multiple of vector length %d of arg %d",
-                                nvar, ni, i), domain = NA)
+                    warning(
+                        gettextf(
+                            paste(
+                                "number of columns of result, %d, is not a",
+                                "multiple of vector length %d of arg %d"
+                            ),
+                            nvar, ni, i),
+                        domain = NA
+                    )
                 xi <- rep_len(xi, nvar)
                     }
             ri <- rows[[i]]
@@ -368,8 +412,14 @@
                             .row_names_info(xij) <= 0))
                             rownames(value[[jj]])[ri] <- r
                 } else {
-                        value[[jj]][ri] <- if(is.factor(xij)) as.vector(xij) else xij
-                        if(!is.null(nm <- names(xij))) names(value[[jj]])[ri] <- nm
+                        value[[jj]][ri] <- if(is.factor(xij)) {
+                            as.vector(xij)
+                        } else {
+                            xij
+                        }
+                        if(!is.null(nm <- names(xij))) {
+                            names(value[[jj]])[ri] <- nm
+                        }
                     }
             }
             }
@@ -404,8 +454,17 @@
             method = c("auto", "shell", "radix"), empty.last = na.last) {
             z <- list(...)
             decreasing <- as.logical(decreasing)
-            if (length(z) == 1L && is.numeric(x <- z[[1L]]) && !is.object(x) && length(x) > 0) {
-                if (eval(parse(text = ".Internal(sorted_fpass(x, decreasing, na.last))"))) {
+            if (
+                length(z) == 1L &&
+                is.numeric(x <- z[[1L]]) &&
+                !is.object(x) &&
+                length(x) > 0
+            ) {
+                if (
+                    eval(parse(
+                        text = ".Internal(sorted_fpass(x, decreasing, na.last))"
+                    ))
+                ) {
                     return(seq_along(x))
                 }
             }
@@ -421,19 +480,35 @@
             }
             if (method == "auto") {
                 useRadix <- all(vapply(z, function(x) {
-                    (is.numeric(x) || is.factor(x) || is.logical(x)) && is.integer(length(x))
+                    (
+                        is.numeric(x) ||
+                        is.factor(x) ||
+                        is.logical(x)
+                    ) &&
+                    is.integer(length(x))
                 }, logical(1L)))
                 method <- ifelse (useRadix, "radix", "shell")
             }
             if (length(z) == 1L && is.declared(x)) {
-                return(order_declared(x, na.last = na.last, decreasing = decreasing, method = method, empty.last = empty.last))
+                return(order_declared(
+                    x, na.last = na.last, decreasing = decreasing,
+                    method = method, empty.last = empty.last
+                ))
             }
             if (method != "radix" && !is.na(na.last)) {
-                return(eval(parse(text = ".Internal(order(na.last, decreasing, ...))")))
+                return(eval(parse(
+                    text = ".Internal(order(na.last, decreasing, ...))"
+                )))
             }
             if (method == "radix") {
                 decreasing <- rep_len(as.logical(decreasing), length(z))
-                return(eval(parse(text = ".Internal(radixsort(na.last, decreasing, FALSE, TRUE, ...))")))
+                return(eval(parse(
+                    text = paste(
+                        ".Internal(radixsort(",
+                        "na.last, decreasing, FALSE, TRUE, ...",
+                        "))"
+                    )
+                )))
             }
             if (any(diff((l.z <- lengths(z)) != 0L))) {
                 stop("argument lengths differ")
@@ -520,6 +595,17 @@
             }
             eval(parse(text = ".Internal(drop(x))"))
         }
+        do.call("unlockBinding", list(sym = "match", env = env))
+        env$match <- function(
+            x, table, nomatch = NA_integer_, incomparables = NULL
+        ) {
+            if (is.declared(x)) {
+                attributes(x) <- NULL
+            }
+            eval(parse(
+                text = ".Internal(match(x, table, nomatch, incomparables))"
+            ))
+        }
     }
     if (unlockEnvironment_(asNamespace("stats"))) {
         env <- as.environment("package:stats")
@@ -532,7 +618,12 @@
                 }
                 class(x) <- setdiff(class(x), "declared")
             }
-            sqrt(var(if (is.vector(x) || is.factor(x)) x else as.double(x), na.rm = na.rm))
+            sqrt(
+                var(
+                    if (is.vector(x) || is.factor(x)) x else as.double(x),
+                    na.rm = na.rm
+                )
+            )
         }
         do.call("unlockBinding", list(sym = "var", env = env))
         env$var <- function(x, y = NULL, na.rm = FALSE, use) {
@@ -546,8 +637,13 @@
             if (missing(use)) {
                 use <- ifelse(na.rm, "na.or.complete", "everything")
             }
-            na.method <- pmatch(use, c("all.obs", "complete.obs", "pairwise.complete.obs",
-                "everything", "na.or.complete"))
+            na.method <- pmatch(
+                use,
+                c(
+                    "all.obs", "complete.obs", "pairwise.complete.obs",
+                    "everything", "na.or.complete"
+                )
+            )
             if (is.na(na.method)) {
                 stop("invalid 'use' argument")
             }
@@ -631,7 +727,7 @@
     else {
         stopifnot(is.function(fun))
     }
-    if (pkg %in% loadedNamespaces()) {
+    if (is.element(pkg, loadedNamespaces())) {
         registerS3method(generic, class, fun, envir = asNamespace(pkg))
     }
     setHook(
